/**
 * A Map that tracks reference counts for keys.
 */
class ReferenceCounter {
  refCount = new Map();
  /**
   * Increment the refCount for the given key.
   *
   * @returns true if the given key is new.
   */
  increment(key) {
    const current = this.refCount.get(key);
    if (current === undefined) {
      this.refCount.set(key, 1);
      return true;
    }
    this.refCount.set(key, current + 1);
    return false;
  }
  /**
   * Decrements the refCount for the given key.
   *
   * @returns true if this was the given key's last reference.
   */
  decrement(key) {
    const current = this.refCount.get(key);
    if (current === undefined) {
      throw new Error(`No refCount for key: ${String(key)}`);
    } else if (current === 1) {
      this.refCount.delete(key);
      return true;
    } else {
      this.refCount.set(key, current - 1);
      return false;
    }
  }
  /**
   * Returns an iterable of registered keys.
   */
  keys() {
    return this.refCount.keys();
  }
  delete(key) {
    return this.refCount.delete(key);
  }
}

export { ReferenceCounter };
//# sourceMappingURL=reference-counter.js.map
